@@ -210,41 +210,44 @@ def parse_client_io_data(client, io_data):
         LOGGER.error('Response from client %s does not contain disk I/O statistics', client.host_name)
 
 
-def get_stats_from_client(client):
+def get_stats_from_client(client, update_interval):
     """Shoots the HTTP request. Gets response body and calls parse_client_io_data
 
     """
-    io_data = None
-    http_response = None
+    while True:
+        io_data = None
+        http_response = None
 
-    ping_resp = client_ping_response(client)
-    if ping_resp == 0:
-        client.is_unreachable = False
-        try:
-            LOGGER.info('Requesting stats from %s', client.host_name)
-            http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
-            http_conn.request('GET', '/')
-            http_response = http_conn.getresponse()
-        except:
-            LOGGER.warning('Client %s does not have xsanio_client installed', client.host_name)
-            client.has_client_installed = False
-            client.save()
-            return
+        ping_resp = client_ping_response(client)
+        if ping_resp == 0:
+            client.is_unreachable = False
+            try:
+                LOGGER.info('Requesting stats from %s', client.host_name)
+                http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
+                http_conn.request('GET', '/')
+                http_response = http_conn.getresponse()
+            except:
+                LOGGER.warning('Client %s does not have xsanio_client installed', client.host_name)
+                client.has_client_installed = False
+                client.save()
+                return
 
 
-        if http_response.status == 200:
-            client.has_client_installed = True
-            client.save()
-            host_response_data = http_response.read()
-            io_data = json.loads(host_response_data)
-            parse_client_io_data(client, io_data)
-            LOGGER.info('Finished parsing response from %s', client.host_name)
+            if http_response.status == 200:
+                client.has_client_installed = True
+                client.save()
+                host_response_data = http_response.read()
+                io_data = json.loads(host_response_data)
+                parse_client_io_data(client, io_data)
+                LOGGER.info('Finished parsing response from %s', client.host_name)
+            else:
+                LOGGER.info("Client %s responded with %s", client.host_name, http_response.status)
         else:
-            LOGGER.info("Client %s responded with %s", client.host_name, http_response.status)
-    else:
-        client.is_unreachable = True
-        LOGGER.info('Client %s responded to ping with %s', client.host_name, ping_resp)
-        client.save()
+            client.is_unreachable = True
+            LOGGER.info('Client %s responded to ping with %s', client.host_name, ping_resp)
+            client.save()
+
+        time.sleep(update_interval)
 
 
 def discover_clients(xsan_config_dir):
@@ -296,6 +299,7 @@ def update_clients():
     global XSAN_CONFIG_DIR
     global XSAN_VOLUME_CONFIG_REGEX
     global XSAN_CONFIG_NODE_REGEX
+    global CLIENT_UPDATE_DELAY
 
     processes = []
 
@@ -303,7 +307,7 @@ def update_clients():
         LOGGER.info('Getting stats for %s', client)
         processes.append(multiprocessing.Process(
             target=get_stats_from_client,
-            args=(client, )
+            args=(client, CLIENT_UPDATE_DELAY, )
         ))
 
     for process in processes:
@@ -329,7 +333,5 @@ def main():
 
     discover_clients(XSAN_CONFIG_DIR)
 
-    while True:
-        update_clients()
-        time.sleep(CLIENT_UPDATE_DELAY)
+    update_clients()
 
